@@ -47,8 +47,8 @@ chunk s = case Prelude.lex s of
 isLinearSpace c = c `elem` " \t\f" -- " \t\xa0"
 
 -- Glue sequences of tokens into more useful blobs
---glue (q:".":n:rest) | Char.isUpper (head q)	-- qualified names
---                    = glue ((q++"."++n): rest)
+glue (q:".":n:rest) | isUpper (head q)	-- qualified names
+                    = glue ((q++"."++n): rest)
 glue ("`":rest) =				-- `varid` -> varop
   case glue rest of
     (qn:"`":rest) -> ("`"++qn++"`"): glue rest
